.. _examples-datasets:

Datasets
========

The :mod:`pulse2percept.datasets` module provides helper functions
that can be used to load datasets from the bionic vision community,
such as :py:func:`~pulse2percept.datasets.load_horsager2009`,
:py:func:`~pulse2percept.datasets.fetch_beyeler2019`,
:py:func:`~pulse2percept.datasets.load_nanduri2012` and
:py:func:`~pulse2percept.datasets.load_fornos2012`.